Integer Wavelet Transform (CDF 5/3) for Layer 1 skeleton
Implements the Cohen-Daubechies-Feauveau 5/3 biorthogonal wavelet using the lifting scheme with all operations in integers for perfect reconstruction and deterministic behavior.
Structs
- Cdf53
Transform - CDF 5/3 Integer Wavelet Transform
- Wavelet
Decomposition - Wavelet decomposition structure (Compressed)
Enums
- SubBand
- Wavelet subband type